==> gftools-0.9.33-py3-none-any.whl: gftools/scripts/gen_push_lists.py <==
#!/usr/bin/env python3
"""
Generate the to_production.txt and to_sandbox.txt server files in a local
google/fonts repository.

to_production.txt file tells the engineers which directories need to be pushed
to the production server. Likewise, the to_sandbox.txt file is for directories
to be pushed to the sandbox server.

In order for this script to work, the traffic jam must be kept up to date and
pull requests must use labels.

Usage:
gftools gen-push-lists /path/to/google/fonts
"""
import sys
import os
from gftools.push import (
    PushItems,
    PushStatus,
    PushList,
    branch_matches_google_fonts_main,
)


def main(args=None):
    if len(sys.argv) != 3:
        print("Usage: gftools gen-push-lists /path/to/google/fonts")
        sys.exit()

    gf_path = sys.argv[2]
    if not "ofl" in os.listdir(gf_path):
        raise ValueError(
            f"'{gf_path}' does not contain an 'ofl' dir so it isn't a google/fonts repo."
        )
    cwd = os.getcwd()

    os.chdir(gf_path)
    branch_matches_google_fonts_main(gf_path)
    to_sandbox_fp = os.path.join(gf_path, "to_sandbox.txt")
    to_production_fp = os.path.join(gf_path, "to_production.txt")

    # get existing push items
    board_items = PushItems.from_traffic_jam()
    sandbox_file = PushItems.from_server_file(
        to_sandbox_fp, PushStatus.IN_DEV, PushList.TO_SANDBOX
    )
    production_file = PushItems.from_server_file(
        to_production_fp, PushStatus.IN_SANDBOX, PushList.TO_PRODUCTION
    )

    sandbox_board = board_items.to_sandbox()
    production_board = board_items.to_production()
    live_board = board_items.live()

    to_sandbox = (sandbox_file + sandbox_board) - production_board
    to_production = (production_file + production_board) - live_board

    to_sandbox.to_server_file(to_sandbox_fp)
    to_production.to_server_file(to_production_fp)

    os.chdir(cwd)


if __name__ == "__main__":
    main()

==> gftools-0.9.49-py3-none-any.whl: gftools/scripts/gen_push_lists.py <==
#!/usr/bin/env python3
"""
Generate the to_production.txt and to_sandbox.txt server files in a local
google/fonts repository.

to_production.txt file tells the engineers which directories need to be pushed
to the production server. Likewise, the to_sandbox.txt file is for directories
to be pushed to the sandbox server.

In order for this script to work, the traffic jam must be kept up to date and
pull requests must use labels.

Usage:
gftools gen-push-lists /path/to/google/fonts
"""
import sys
import os
from gftools.push.trafficjam import (
    PushItems,
    PushStatus,
    PushList,
)
from gftools.push.utils import branch_matches_google_fonts_main


def main(args=None):
    if len(sys.argv) != 3:
        print("Usage: gftools gen-push-lists /path/to/google/fonts")
        sys.exit()

    gf_path = sys.argv[2]
    if not "ofl" in os.listdir(gf_path):
        raise ValueError(
            f"'{gf_path}' does not contain an 'ofl' dir so it isn't a google/fonts repo."
        )
    cwd = os.getcwd()

    os.chdir(gf_path)
    branch_matches_google_fonts_main(gf_path)
    to_sandbox_fp = os.path.join(gf_path, "to_sandbox.txt")
    to_production_fp = os.path.join(gf_path, "to_production.txt")

    # get existing push items
    board_items = PushItems.from_traffic_jam()
    sandbox_file = PushItems.from_server_file(
        to_sandbox_fp, PushStatus.IN_DEV, PushList.TO_SANDBOX
    )
    production_file = PushItems.from_server_file(
        to_production_fp, PushStatus.IN_SANDBOX, PushList.TO_PRODUCTION
    )

    sandbox_board = board_items.to_sandbox()
    production_board = board_items.to_production()
    live_board = board_items.live()

    to_sandbox = (sandbox_file + sandbox_board) - production_board
    to_production = (production_file + production_board) - live_board

    to_sandbox.to_server_file(to_sandbox_fp)
    to_production.to_server_file(to_production_fp)

    os.chdir(cwd)


if __name__ == "__main__":
    main()
